@@ -74,13 +74,17 @@ def flag_washout(df_well, y_pred=None, **kwargs):
     print('Method: washout...')
 
     y_pred = get_outliers(df_well, y_pred)
+    if not 'score_washout_gen' in y_pred.columns:
+        y_pred.loc[:, 'score_washout_gen'] = 0
     rolling_window = kwargs.get('washout_rolling_window', 101)
     for bsr in y_pred['BS_region'].unique():
         df_gr = y_pred[y_pred['BS_region']==bsr].copy()
         rows_with_values = df_gr[df_gr['CALI'].isna()==False].index
         if len(rows_with_values):
-            df_gr.loc[rows_with_values, 'CALI_std'] = df_gr.loc[rows_with_values, 'CALI'].rolling(rolling_window).std().fillna(0)
-            y_pred.loc[rows_with_values, 'score_washout_gen'] = np.abs(standardizer(df_gr.loc[rows_with_values, 'CALI_std'].values.reshape(-1,1)))
+            df_gr.loc[rows_with_values, 'CALI_std'] =\
+                df_gr.loc[rows_with_values, 'CALI'].rolling(rolling_window).std().fillna(0)
+            y_pred.loc[rows_with_values, 'score_washout_gen'] =\
+                np.abs(standardizer(df_gr.loc[rows_with_values, 'CALI_std'].values.reshape(-1,1)))
 
     y_pred['score_washout_gen'].fillna(0, inplace=True)
     return y_pred
\ No newline at end of file
